@@ -1,6 +1,5 @@
 package Compress::BGZF::Reader;
 
-use 5.012000;
 use strict;
 use warnings;
 
@@ -301,7 +300,7 @@ sub getline {
     while (1) {
 
         # return immediately if EOF
-        return $data if ($self->{buffer_len} < 0);
+        last if ($self->{buffer_len} < 0);
 
         # search current block for record separator
         # start searching from the current buffer offset
@@ -319,7 +318,7 @@ sub getline {
 
             $self->{u_offset} += length($data);
 
-            return $data;
+            last;
 
         }
 
@@ -329,7 +328,7 @@ sub getline {
 
     }
 
-    return;
+    return length($data) > 0 ? $data : undef;
 
 }
 
@@ -537,6 +536,18 @@ sub _seek {
 
 }
 
+sub get_vo {
+
+    #-------------------------------------------------------------------------
+    # no arguments
+    #-------------------------------------------------------------------------
+    # RET 0 : virtual offset of current position
+    #-------------------------------------------------------------------------
+
+    my ($self) = @_;
+    return  ($self->{block_offset} << 16) | $self->{buffer_offset};
+
+}
 
 sub move_to_vo {
 
@@ -588,10 +599,6 @@ __END__
 
 Compress::BGZF::Reader - Performs blocked GZIP (BGZF) decompression
 
-=head1 VERSION
-
-version 0.002
-
 =head1 SYNOPSIS
 
     use Compress::BGZF::Reader;
@@ -691,11 +698,17 @@ offset and the relativity of the offset (0: file start, 1: current, 2: file end)
 
 =item B<move_to_vo>
 
-    $reader->move_to( $virt_offset );
+    $reader->move_to_vo( $virt_offset );
 
 Like C<move_to>, but takes as a single argument a virtual offset. Virtual
 offsets are described more in the top-level documentation for C<Compress::BGZF>.
 
+=item B<get_vo>
+
+    $reader->get_vo();
+
+Returns the virtual offset of the current read position
+
 =item B<read_data>
 
     my $data = $reader->read_data( 32 );
